@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "database.h"
 #include "transfer.h"
 #include <QSqlQuery>
@@ -12,13 +29,13 @@
 #include <QDesktopServices>
 #endif
 
-Database* Database::m_instance = 0;
+Database* Database::self = 0;
 
 Database::Database() :
     QObject()
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 #if QT_VERSION >= 0x050000
     QString path(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/.QDL/");
@@ -41,7 +58,7 @@ Database::Database() :
 Database::~Database() {}
 
 Database* Database::instance() {
-    return !m_instance ? new Database : m_instance;
+    return !self ? new Database : self;
 }
 
 void Database::initialize() {
