@@ -1,5 +1,21 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "utils.h"
-#include <QDateTime>
 #include <QFileInfo>
 #include <QFile>
 #ifndef QML_USER_INTERFACE
@@ -8,6 +24,13 @@
 #include <QImage>
 #endif
 
+Utils::Utils(QObject *parent) :
+    QObject(parent)
+{
+}
+
+Utils::~Utils() {}
+
 QString Utils::durationFromSecs(int secs) {
     QTime time(0, 0);
     QString format = secs >= 3600 ? "hh:mm:ss" : "mm:ss";
