@@ -33,6 +33,10 @@ var limitPerPage = document.URL.indexOf("limit=") > 0 ? parseInt(document.URL.sp
 var filter = document.URL.indexOf("filter=") > 0 ? document.URL.split("filter=")[1].split("&")[0] : "";
 var query = document.URL.indexOf("query=") > 0 ? document.URL.split("query=")[1].split("&")[0] : "";
 
+var captchaId = "";
+var captchaFileName = "";
+var captchaTimeOut = 0;
+
 function init() {
     /* Connect handlers */
     
@@ -51,6 +55,14 @@ function init() {
     document.getElementById("retrieveUrlsEdit").onchange = function() {
         document.getElementById("retrieveUrlsButton").disabled = (this.value == "");
     }
+
+    document.getElementById("captchaResponseEdit").onkeyup = function() {
+        document.getElementById("submitCaptchaButton").disabled = (this.value == "");
+    }
+
+    document.getElementById("captchaResponseEdit").onchange = function() {
+        document.getElementById("submitCaptchaButton").disabled = (this.value == "");
+    }
     
     /* Load data */
     
@@ -103,7 +115,18 @@ function init() {
                                         transfers = JSON.parse(request.responseText).transfers;
                                         
                                         for (var i = 0; i < transfers.length; i++) {
-                                            appendRow(transfers[i]);
+                                            var transfer = transfers[i];
+                                            appendRow(transfer);
+
+                                            if ((transfer.status == 8) && (!captchaId)) {
+                                                captchaId = transfer.id;
+                                                captchaFileName = transfer.captchaFileName;
+                                                captchaTimeOut = transfer.captchaTimeOut;
+                                            }
+                                        }
+
+                                        if (captchaId) {
+                                            showCaptchaDialog();
                                         }
                                     }
                                 }
@@ -125,6 +148,52 @@ function init() {
     request.send(null);
 }
 
+function showCaptchaDialog() {
+    /* Display the captcha dialog enabling the user to submit a captcha response */
+
+    document.getElementById("dialogBackground").style.display = "block";
+    document.getElementById("captchaDialog").style.display = "block";
+    document.getElementById("captchaImage").src = captchaFileName;
+    document.getElementById("captchaResponseEdit").select();
+    document.getElementById("captchaTimeOut").innerHTML = formatSecs(captchaTimeOut);
+    window.setTimeout(updateCaptchaDialog, 1000);
+}
+
+function updateCaptchaDialog() {
+    /* Update the captcha timeout value in the captcha dialog */
+
+    captchaTimeOut--;
+
+    if (captchaTimeOut > 0) {
+        document.getElementById("captchaTimeOut").innerHTML = formatSecs(captchaTimeOut);
+        window.setTimeout(updateCaptchaDialog, 1000);
+    }
+    else {
+        hideCaptchaDialog();
+    }
+}
+
+function hideCaptchaDialog() {
+    document.getElementById("captchaDialog").style.display = "none";
+    document.getElementById("dialogBackground").style.display = "none";
+    document.getElementById("captchaResponseEdit").value = "";
+}
+
+function submitCaptcha() {
+    /* Submit the captcha response */
+
+    var response = document.getElementById("captchaResponseEdit").value;
+    setTransferProperty(captchaId, "captchaResponse", response);
+    hideCaptchaDialog();
+}
+
+function cancelCaptcha() {
+    /* Cancel the captcha submission by submitting an empty string as the response */
+
+    setTransferProperty(captchaId, "captchaResponse", "");
+    hideCaptchaDialog();
+}
+
 function showAddUrlsDialog(urls) {
     /* Display the dialog to add URLs */
    
@@ -828,7 +897,7 @@ function setMaximumConcurrentTransfers() {
         }
     }
 
-    request.open("GET", "preferences/setProperty?property=maximumConcurrentTransfers&value=" + maximum);
+    request.open("GET", "preferences/setProperties?maximumConcurrentTransfers=" + maximum);
     request.send(null);
 }
 
@@ -848,7 +917,7 @@ function setMaximumConnectionsPerTransfer() {
         }
     }
 
-    request.open("GET", "preferences/setProperty?property=maximumConnectionsPerTransfer&value=" + maximum);
+    request.open("GET", "preferences/setProperties?maximumConnectionsPerTransfer=" + maximum);
     request.send(null);
 }
 
@@ -868,6 +937,6 @@ function setDownloadRateLimit() {
         }
     }
 
-    request.open("GET", "preferences/setProperty?property=downloadRateLimit&value=" + limit);
+    request.open("GET", "preferences/setProperties?downloadRateLimit=" + limit);
     request.send(null);
-}
\ No newline at end of file
+}
